@@ -384,16 +384,32 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE)
                 attr(xx$depvars[[j]], "nodeSet") == nodeSet)
             {
 				depvarname <- names(xx$depvars)[j]
-                tmpObjEffects <-
-					createEffects("behaviorOneModeObjective",
-								  varname, depvarname, name=varname,
-								  groupName=groupName, group=group,
-								  netType=netType)
-				tmpRateEffects <-
-					createEffects("behaviorOneModeRate",
-								  varname, depvarname, name=varname,
-								  groupName=groupName, group=group,
-								  netType=netType)
+				if (attr(xx$depvars[[j]], "symmetric"))
+				{
+					tmpObjEffects <-
+						createEffects("behaviorSymmetricObjective",
+									  varname, depvarname, name=varname,
+									  groupName=groupName, group=group,
+									  netType=netType)
+					tmpRateEffects <-
+						createEffects("behaviorSymmetricRate",
+									  varname, depvarname, name=varname,
+									  groupName=groupName, group=group,
+									  netType=netType)
+				}
+				else
+				{
+					tmpObjEffects <-
+						createEffects("behaviorOneModeObjective",
+									  varname, depvarname, name=varname,
+									  groupName=groupName, group=group,
+									  netType=netType)
+					tmpRateEffects <-
+						createEffects("behaviorOneModeRate",
+									  varname, depvarname, name=varname,
+									  groupName=groupName, group=group,
+									  netType=netType)
+				}
 				if ((nOneModes + nBipartites) > 1) ## add the network name
 				{
 					tmpObjEffects$functionName <-
@@ -812,12 +828,12 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE)
                                          netType=netType)
         }
 
-       covRateEffects <- createEffects("covarBehaviorRate", varname, covarname,
+        covRateEffects <- createEffects("covarBehaviorRate", varname, covarname,
                                         name=name,
                                         groupName=groupName, group=group,
-                                         netType=netType)
+                                        netType=netType)
         ## if we have a real covariate, need to add other effects for every
-        ## approriate network
+        ## appropriate network
         if (!same)
         {
             for (j in seq(along=xx$depvars))
@@ -825,24 +841,24 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE)
                 if (types[j] == 'oneMode' &&
                     attr(xx$depvars[[j]], 'nodeSet') == nodeSet)
                 {
-					newEffects <-
-						createEffects("covarBehaviorNetObjective", varname,
-									  covarname, names(xx$depvars)[j],
-									  groupName=groupName, group=group,
-									  netType=netType, name=name)
+                    newEffects <-
+                        createEffects("covarBehaviorNetObjective", varname,
+                                      covarname, names(xx$depvars)[j],
+                                      groupName=groupName, group=group,
+                                      netType=netType, name=name)
 
                     covObjEffects <- rbind(covObjEffects, newEffects)
 				}
                 if ((types[j] == "bipartite" &&
-                        attr(xx$depvars[[j]], 'nodeSet')[2] == nodeSet))
+                     attr(xx$depvars[[j]], 'nodeSet')[2] == nodeSet))
                 {
-  					newEffects <-
-						createEffects("covarBehaviorBipartiteObjective", varname,
-									  covarname, names(xx$depvars)[j],
-									  groupName=groupName, group=group,
-									  netType=netType, name=name)
-                  covObjEffects <- rbind(covObjEffects, newEffects)
-				}
+                    newEffects <-
+                        createEffects("covarBehaviorBipartiteObjective", varname,
+                                      covarname, names(xx$depvars)[j],
+                                      groupName=groupName, group=group,
+                                      netType=netType, name=name)
+                    covObjEffects <- rbind(covObjEffects, newEffects)
+                }
             }
         }
 
