@@ -19,8 +19,6 @@
 #include "BehaviorInteractionEffect.h"
 #include "BetweennessEffect.h"
 #include "CovariateAlterEffect.h"
-#include "CovariateDistance2AlterEffect.h"
-#include "CovariateDistance2SimilarityEffect.h"
 #include "CovariateEgoAlterEffect.h"
 #include "CovariateEgoEffect.h"
 #include "CovariateIndirectTiesEffect.h"
