@@ -164,16 +164,76 @@ double BehaviorEffect::egoStatistic(int ego, double * currentValues)
 
 /**
  * Returns the statistic corresponding to this effect as part of
+ * the endowment function with respect to the given values of
+ * the behavior variable.
+ */
+double BehaviorEffect::endowmentStatistic(const int * difference,
+	double * currentValues)
+{
+	double statistic = 0;
+	int n = this->n();
+
+	for (int i = 0; i < n; i++)
+	{
+		this->preprocessEgo(i);
+		if (!this->missing(this->period(), i))
+		{
+			statistic += this->egoEndowmentStatistic(i, difference,
+				currentValues);
+		}
+	}
+
+	return statistic;
+}
+/**
+ * Returns the statistic corresponding the given ego as part of
  * the endowment function with respect to an initial behavior
  * variable and the current state.
  */
-double BehaviorEffect::endowmentStatistic(const int * difference,
+double BehaviorEffect::egoEndowmentStatistic(int i, const int * difference,
 	double *currentValues)
 {
-	throw runtime_error("endowmentStatistic not implemented for " +
+	throw runtime_error("egoEndowmentStatistic not implemented for " +
 		this->pEffectInfo()->effectName());
 }
 
+
+/**
+ * Returns the statistic corresponding to this effect as part of
+ * the creation function.
+ * @param[in] difference an array of differences per each actor where the
+ * current value is subtracted from the initial value. Thus positive
+ * differences indicate a decrease of actors' behavior, while negative values
+ * indicate an increase of actors' behavior.
+ * @param[in] currentValues the current state of the behavior variable
+ */
+double BehaviorEffect::creationStatistic(int * difference,
+	double *currentValues)
+{
+	// Here we use a trick. The creation statistics are very similar to the
+	// endowmnent statistics, but instead of summing over all actors with
+	// decreasing values, we must now sum over all actors with increasing
+	// values. So we just reverse the differences and call the endowment
+	// statistic.
+
+	int n = this->n();
+
+	for (int i = 0; i < n; i++)
+	{
+		difference[i]  = -difference[i];
+	}
+
+	double statistic = this->endowmentStatistic(difference, currentValues);
+
+	for (int i = 0; i < n; i++)
+	{
+		difference[i]  = -difference[i];
+	}
+
+	return -statistic;
+}
+
+
 /**
  * Does the necessary preprocessing work for calculating the probabilities
  * for a specific ego. This method must be invoked before
