@@ -30,10 +30,18 @@ public:
 		int requiredTwoPathCount);
 
 	virtual double calculateContribution(int alter) const;
-	virtual double evaluationStatistic() const;
-	virtual double endowmentStatistic(Network * pLostTieNetwork) const;
+	virtual double endowmentStatistic(Network * pLostTieNetwork);
+
+protected:
+	virtual void initializeStatisticCalculation();
+	virtual double egoStatistic(int ego,
+		const Network * pSummationTieNetwork);
+	virtual void cleanupStatisticCalculation();
 
 private:
+	// A helper array of marks for statistic calculation
+	int * lmark;
+
 	int lrequiredTwoPathCount;
 };
 
