@@ -46,7 +46,7 @@ public:
 	virtual double calculateContribution(int alter) const;
 
 protected:
-	virtual double statistic(const Network * pSummationTieNetwork) const;
+	virtual double tieStatistic(int alter);
 
 private:
 	void countThreePaths(int i, const Network * pNetwork, int * counters)
