@@ -29,26 +29,19 @@ QuadraticShapeEffect::QuadraticShapeEffect(const EffectInfo * pEffectInfo) :
  * the given actor would change his behavior by the given amount.
  */
 double QuadraticShapeEffect::calculateChangeContribution(int actor,
-	int difference) const
+	int difference)
 {
 	return (2 * this->centeredValue(actor) + difference) * difference;
 }
 
+
 /**
- * Returns the statistic corresponding to this effect as part of
- * the evaluation function with respect to the given behavior variable.
+ * Returns the statistic corresponding to the given ego with respect to the
+ * given values of the behavior variable.
  */
-double QuadraticShapeEffect::evaluationStatistic(double * currentValues) const
+double QuadraticShapeEffect::egoStatistic(int ego, double * currentValues)
 {
-	double statistic = 0;
-	int n = this->n();
-
-	for (int i = 0; i < n; i++)
-	{
-		statistic += currentValues[i] * currentValues[i];
-	}
-
-	return statistic;
+	return currentValues[ego] * currentValues[ego];
 }
 
 
@@ -58,7 +51,7 @@ double QuadraticShapeEffect::evaluationStatistic(double * currentValues) const
  * behavior variable and the current values.
  */
 double QuadraticShapeEffect::endowmentStatistic(const int * difference,
-	double * currentValues) const
+	double * currentValues)
 {
 	double statistic = 0;
 	int n = this->n();
