@@ -1212,7 +1212,6 @@ void NetworkVariable::accumulateSymmetricModelScores(int alter, bool accept)
 				score = -1 * this->lsymmetricEvaluationEffectContribution[0][i]
 					* prEgo;
 			}
-
 			this->pSimulation()->score(pEffect->pEffectInfo(),
 				this->pSimulation()->score(pEffect->pEffectInfo()) + score);
 		}
@@ -1236,14 +1235,14 @@ void NetworkVariable::accumulateSymmetricModelScores(int alter, bool accept)
 					score =  -1  * prEgo *
 						this->lsymmetricEndowmentEffectContribution[0][i];
 				}
+				this->pSimulation()->score(pEffect->pEffectInfo(),
+					this->pSimulation()->score(pEffect->pEffectInfo()) + score);
 			}
-			this->pSimulation()->score(pEffect->pEffectInfo(),
-				this->pSimulation()->score(pEffect->pEffectInfo()) + score);
 		}
 
 		for (unsigned i = 0;
-			i < this->pCreationFunction()->rEffects().size();
-			i++)
+			 i < this->pCreationFunction()->rEffects().size();
+			 i++)
 		{
 			Effect * pEffect = this->pCreationFunction()->rEffects()[i];
 
@@ -1253,17 +1252,16 @@ void NetworkVariable::accumulateSymmetricModelScores(int alter, bool accept)
 				{
 					score =
 						this->lsymmetricCreationEffectContribution[0][i] *
-							(1 - prEgo);
+						(1 - prEgo);
 				}
 				else
 				{
 					score =  -prEgo *
 						this->lsymmetricCreationEffectContribution[0][i];
 				}
+				this->pSimulation()->score(pEffect->pEffectInfo(),
+					this->pSimulation()->score(pEffect->pEffectInfo()) + score);
 			}
-
-			this->pSimulation()->score(pEffect->pEffectInfo(),
-				this->pSimulation()->score(pEffect->pEffectInfo()) + score);
 		}
 
 		break;
@@ -1302,7 +1300,7 @@ void NetworkVariable::accumulateSymmetricModelScores(int alter, bool accept)
 					score = (1 - prEgo) * (1 - prAlter) *
 						(this->lsymmetricEvaluationEffectContribution[0][i]
 							* prEgo +
-						this->lsymmetricEvaluationEffectContribution[1][i]
+							this->lsymmetricEvaluationEffectContribution[1][i]
 							* prAlter) /
 						(prEgo + prAlter - prEgo * prAlter);
 				}
@@ -1345,10 +1343,10 @@ void NetworkVariable::accumulateSymmetricModelScores(int alter, bool accept)
 								lsymmetricEndowmentEffectContribution[1][i]
 								* prAlter));
 				}
-			}
 
-			this->pSimulation()->score(pEffect->pEffectInfo(),
-				this->pSimulation()->score(pEffect->pEffectInfo()) + score);
+				this->pSimulation()->score(pEffect->pEffectInfo(),
+					this->pSimulation()->score(pEffect->pEffectInfo()) + score);
+			}
 		}
 
 		for (unsigned i = 0;
@@ -1376,10 +1374,10 @@ void NetworkVariable::accumulateSymmetricModelScores(int alter, bool accept)
 							this->lsymmetricCreationEffectContribution[1][i] *
 							prAlter);
 				}
+				this->pSimulation()->score(pEffect->pEffectInfo(),
+					this->pSimulation()->score(pEffect->pEffectInfo()) + score);
 			}
 
-			this->pSimulation()->score(pEffect->pEffectInfo(),
-				this->pSimulation()->score(pEffect->pEffectInfo()) + score);
 		}
 
 		break;
@@ -1636,7 +1634,7 @@ bool NetworkVariable::calculateModelTypeBProbabilities()
 		}
 	}
 
-	this->lalterProbability = this->rate(alter) / cumulativeRates[this->n()];
+	this->lalterProbability = this->rate(alter) / cumulativeRates[this->n() - 1];
 
 	delete [] cumulativeRates;
 
