@@ -93,7 +93,8 @@ SEXP deleteModel(SEXP RpModel);
  *  sets up the model options of MAXDEGREE, CONDITIONAL
  */
 SEXP setupModelOptions(SEXP DATAPTR, SEXP MODELPTR, SEXP MAXDEGREE,
-	SEXP CONDVAR, SEXP CONDTARGETS, SEXP PROFILEDATA, SEXP PARALLELRUN);
+	SEXP CONDVAR, SEXP CONDTARGETS, SEXP PROFILEDATA, SEXP PARALLELRUN,
+	SEXP MODELTYPE, SEXP SIMPLERATES);
 
 /**
  *  Gets target values relative to the input data
@@ -104,14 +105,14 @@ SEXP getTargets(SEXP DATAPTR, SEXP MODELPTR, SEXP EFFECTSLIST);
  * Processes a complete set of data objects, crewating a chain for each
  * period and storing them on the model object.
  */
-SEXP mlMakeChains(SEXP DATAPTR, SEXP MODELPTR, SEXP SIMPLERATES,
+SEXP mlMakeChains(SEXP DATAPTR, SEXP MODELPTR,
 	SEXP PROBS, SEXP PRMIN, SEXP PRMIB, SEXP MINIMUMPERM,
 	SEXP MAXIMUMPERM, SEXP INITIALPERM);
 
 /**
  *
  */
-SEXP mlInitializeSubProcesses(SEXP DATAPTR, SEXP MODELPTR, SEXP SIMPLERATES,
+SEXP mlInitializeSubProcesses(SEXP DATAPTR, SEXP MODELPTR,
 	SEXP PROBS, SEXP PRMIN, SEXP PRMIB, SEXP MINIMUMPERM,
 	SEXP MAXIMUMPERM, SEXP INITIALPERM, SEXP CHAINS, SEXP MISSINGCHAINS);
 
